@@ -30,7 +30,7 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 #
-# @(#) $Header: /nfs/jade/vint/CVSROOT/ns-2/tcl/ex/test-suite.tcl,v 1.1.1.1 1996/12/19 03:22:46 mccanne Exp $
+# @(#) $Header: /cvsroot/nsnam/ns-2/tcl/ex/test-suite.tcl,v 1.2 2004/08/17 15:26:51 johnh Exp $
 
 #
 #
@@ -155,7 +155,7 @@ proc finish file {
 	# often we have only one drop and xgraph won't print marks
 	# for data sets with only one point.
 	#
-	exec head -1 temp.d >@ $f
+	exec head -n 1 temp.d >@ $f
 	exec cat temp.d >@ $f
 	close $f
 	exec xgraph -bb -tk -nl -m -x time -y packet temp.rands &
